# swatpy

a set of python modules to work with the Soil and Water Assessment Tool (SWAT2012), including model run, programmatic config edits, simulation readouts and calibration with the fantastic SPOTPY package

[![PyPI version](https://badge.fury.io/py/swatpy.svg)](https://badge.fury.io/py/swatpy) [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.6322023.svg)](https://doi.org/10.5281/zenodo.6322023)

